@@ -33,7 +33,7 @@ class Compute(Backend):
 
     start_action = Action()
     start_action_cat = Category()
-    start_action_cat.attributes = ['graceful', 'acpioff', 'poweroff']
+    start_action_cat.attributes = []
     start_action_cat.scheme = 'http://schemas.ogf.org/occi/infrastructure/compute/action'
     start_action_cat.term = 'start'
     start_action_cat.title = 'Start a compute instance'
@@ -41,7 +41,7 @@ class Compute(Backend):
 
     stop_action = Action()
     stop_action_cat = Category()
-    stop_action_cat.attributes = []
+    stop_action_cat.attributes = ['method']
     stop_action_cat.scheme = 'http://schemas.ogf.org/occi/infrastructure/compute/action'
     stop_action_cat.term = 'stop'
     stop_action_cat.title = 'Stop a compute instance'
@@ -49,7 +49,7 @@ class Compute(Backend):
 
     restart_action = Action()
     restart_action_cat = Category()
-    restart_action_cat.attributes = ['graceful', 'warm', 'cold']
+    restart_action_cat.attributes = ['method']
     restart_action_cat.scheme = 'http://schemas.ogf.org/occi/infrastructure/compute/action'
     restart_action_cat.term = 'restart'
     restart_action_cat.title = 'Restart a compute instance'
@@ -57,7 +57,7 @@ class Compute(Backend):
 
     suspend_action = Action()
     suspend_action_cat = Category()
-    suspend_action_cat.attributes = ['hibernate', 'suspend']
+    suspend_action_cat.attributes = ['method']
     suspend_action_cat.scheme = 'http://schemas.ogf.org/occi/infrastructure/compute/action'
     suspend_action_cat.term = 'suspend'
     suspend_action_cat.title = 'Suspend a compute instance'
@@ -84,7 +84,7 @@ class Compute(Backend):
 
         # trigger your hypervisor to start...
         entity.attributes['occi.compute.state'] = 'inactive'
-        print 'Creating the virtual maching'
+        print 'Creating the virtual machine'
 
     def retrieve(self, entity):
         # trigger your hypervisor to get most up to date information
@@ -317,12 +317,14 @@ class StorageLink(LinkBackend):
     kind.term = 'storagelink'
     kind.title = 'A storage link'
 
-#class IPNetworkingLink(Backend):
-#
-#    pass
-#
-## http://schemas.ogf.org/occi/infrastructure/networkinterface# and the value ipnetworkinterface
-##occi.networkinterface.allocation 
-##occi.networkinterface.gateway 
-##occi.networkinterface.ip 
+class IPNetworkingLink(LinkBackend):
+
+    kind = Mixin()
+    kind.actions = []
+    kind.attributes = ['occi.networkinterface.allocation', 'occi.networkinterface.gateway', 'occi.networkinterface.ip']
+    kind.location = '/ipnetwork/'
+    kind.related = [Link.category]
+    kind.scheme = 'http://schemas.ogf.org/occi/infrastructure'
+    kind.term = 'ipnetworkinterface'
+    kind.title = 'A ip network interface'
 
