@@ -212,7 +212,7 @@ def _to_http_category(kind, extended = False):
             rel_list = []
             for item in kind.related:
                 rel_list.append(repr(item))
-            tmp += '; rel=' + ' '.join(rel_list)
+            tmp += '; rel="' + ' '.join(rel_list) + '"'
         if hasattr(kind, 'location') and kind.location is not '':
             tmp += '; location=' + kind.location
         if hasattr(kind, 'attributes') and len(kind.attributes) > 0:
@@ -307,10 +307,7 @@ def _to_http_attribute(key, value):
     '''
     Creates a HTTP X-OCCI-Attribute rendering.
     '''
-    if value.find(' ') == -1:
-        return key + '=' + value
-    else:
-        return key + '="' + value + '"'
+    return key + '="' + value + '"'
 
 def _from_http_location(location_string):
     '''
@@ -857,7 +854,9 @@ class TextHTMLRendering(Rendering):
         css_string = 'body {font: .8em/normal sans-serif;}'
         css_string += 'div {padding: 1em; margin: 1em;'
         css_string += 'border: 1px solid #73c167;}'
-        css_string += 'table {margin: 1em; border: 1px solid #444;}'
+        css_string += "table {margin: 0.5em;}"
+        css_string += 'td {padding: 0.5em; background: #eee;}'
+        css_string += 'th {padding: 0.5em; background: #ccc;}'
 
     def _get_data(self, body):
         '''
