@@ -111,6 +111,21 @@ class BaseHandler(tornado.web.RequestHandler):
                 self._headers[item] = heads[item]
         self.write(data)
 
+    def _create_key(self, entity):
+        '''
+        Create a key with the hierarchy of the entity encapsulated.
+        
+        @param entity: The entity to create the key for.
+        @type entity: Entity
+        '''
+        if entity.kind.location is not '':
+            key = entity.kind.location
+            key += str(uuid.uuid4())
+        else:
+            key = '/' + str(uuid.uuid4())
+        entity.identifier = key
+        return key
+
     def get_current_user(self):
         if AUTHENTICATION is True:
             return self.get_secure_cookie("pyocci_user")
@@ -148,8 +163,7 @@ class BaseHandler(tornado.web.RequestHandler):
         Returns a list of all resources belonging to the current user.
         '''
         my_resources = []
-        for tmp in RESOURCES.keys():
-            item = RESOURCES[tmp]
+        for item in RESOURCES.values():
             if item.owner == self.get_current_user():
                 my_resources.append(item)
         return my_resources
@@ -177,15 +191,17 @@ class ResourceHandler(BaseHandler):
                 action = parser.to_action(headers, body)
                 backend = registry.get_backend(action.kind)
                 backend.action(entity, action)
+
+                self._send_response(None, 'OK')
             except (ParsingException, AttributeError) as pse:
                 raise HTTPError(400, str(pse))
-        else:
-            # parse the request
+        elif key == '/':
             entity = None
             try:
                 # create the entity
                 entity, links = parser.to_entity(headers, body)
                 entity.owner = self.get_current_user()
+
                 key = self._create_key(entity)
                 backend = registry.get_backend(entity.kind)
                 backend.create(entity)
@@ -202,11 +218,13 @@ class ResourceHandler(BaseHandler):
                     item.idetifier = key
                     item.owner = self.get_current_user()
 
+                self._send_response({'Location': registry.HOST + key}, 'OK')
+
             except (ParsingException, AttributeError) as pse:
                 # TODO: RESOURCES.pop(key)
                 raise HTTPError(400, str(pse))
-
-        self._send_response({'Location': registry.HOST + key}, 'OK')
+        else:
+            raise HTTPError(405)
 
     @tornado.web.authenticated
     def put(self, key):
@@ -309,22 +327,7 @@ class ResourceHandler(BaseHandler):
         else:
             raise HTTPError(404)
 
-    def _create_key(self, entity):
-        '''
-        Create a key with the hierarchy of the entity encapsulated.
-        
-        @param entity: The entity to create the key for.
-        @type entity: Entity
-        '''
-        if entity.kind.location is not '':
-            key = '/users/' + self.get_current_user() + entity.kind.location
-            key += str(uuid.uuid4())
-        else:
-            key = '/users/' + self.get_current_user() + '/' + str(uuid.uuid4())
-        entity.identifier = key
-        return key
-
-class ListHandler(BaseHandler):
+class CollectionHandler(BaseHandler):
     '''
     This class handles listing of resources in REST resource hierarchy and
     listing, adding and removing resource intstance from mixins.
@@ -336,6 +339,8 @@ class ListHandler(BaseHandler):
     # disabling 'Method could be a function' pylint check (I want it here)
     # pylint: disable=R0904,W0221,R0201 
 
+    # TODO: actions on collections
+
     def get_locations(self):
         '''
         Returns a dict with all categories which have locations.
@@ -367,6 +372,49 @@ class ListHandler(BaseHandler):
                 tmp.append(res)
         return tmp
 
+    @tornado.web.authenticated
+    def post(self, key):
+        key = '/' + key + '/'
+        headers, body = self.extract_http_data()
+        parser = self.get_pyocci_parser('Content-Type')
+
+        if key not in self.get_locations():
+            raise HTTPError(406, 'This path is not registered - Please check '
+                            + 'the query interface')
+
+        # parse the request
+        entity = None
+        try:
+            # create the entity
+            entity, links = parser.to_entity(headers, body)
+            entity.owner = self.get_current_user()
+
+            if not key == entity.kind.location:
+                raise HTTPError(406, 'Unable to create a resource instance '
+                                + 'with this kind information at this path.')
+
+            key = self._create_key(entity)
+            backend = registry.get_backend(entity.kind)
+            backend.create(entity)
+
+            RESOURCES[key] = entity
+
+            # handle the links...
+            for item in links:
+                backend = registry.get_backend(item.kind)
+                item.source = key
+                backend.create(item)
+                key = self._create_key(item)
+                RESOURCES[key] = item
+                item.idetifier = key
+                item.owner = self.get_current_user()
+
+            self._send_response({'Location': registry.HOST + key}, 'OK')
+
+        except (ParsingException, AttributeError) as pse:
+            # TODO: RESOURCES.pop(key)
+            raise HTTPError(400, str(pse))
+
     @tornado.web.authenticated
     def get(self, key):
         key = '/' + key + '/'
@@ -411,7 +459,7 @@ class ListHandler(BaseHandler):
                 category = locations[key]
                 entities = parser.get_entities(headers, body)
                 for item in entities:
-                    if item in RESOURCES.keys():
+                    if RESOURCES.has_key(item):
                         res = RESOURCES[item]
                         if category not in res.mixins:
                             res.mixins.append(category)
@@ -434,7 +482,7 @@ class ListHandler(BaseHandler):
                 category = locations[key]
                 entities = parser.get_entities(headers, body)
                 for item in entities:
-                    if item in RESOURCES.keys():
+                    if RESOURCES.has_key(item):
                         RESOURCES[item].mixins.remove(category)
             except ParsingException as pse:
                 raise HTTPError(400, log_message = str(pse))
